# balepy

<h3 align="center"> balepy a Library Python for create bot API in bale application </h3>

> ## Install and Update:
```python
pip install -U balepy
```

> ## START:
```python
from balepy import Bot
bot = Bot("Token")
```

> ## Methods:
### send_Message:
```python
bot.send_Message(chat_id , "text")
```
### getupdate:
```python
bot.getupdate()
```
### getchat:
```python
bot.getchat(chat_id)
```
### getme:
```python
bot.getme()
```

<hr>

> ## Social Media:
#### Rubika : <a href="https://rubika.ir/balepy_lib">balepy_lib</a>